==> webgui_7.8.21.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Spanish/Asset_StoryTopic.pm <==
package WebGUI::i18n::Spanish::Asset_StoryTopic;
use utf8;
our $I18N = {
  'Read more stories' => {
    'lastUpdated' => '1253710295',
    'message' => 'Leer más Noticias.'
  },
  'assetName' => {
    'lastUpdated' => '1253710320',
    'message' => 'Tópico de Noticias'
  },
  'atomUrl' => {
    'lastUpdated' => '1253710334',
    'message' => 'El URL a la Fuente Atom para este Tópico de Noticias.'
  },
  'creationDate' => {
    'lastUpdated' => '1253710354',
    'message' => 'La fecha en que la Noticia fue creada o enviada al Archivo de Noticias, como una época Unix.'
  },
  'deleteIcon' => {
    'lastUpdated' => '1253710389',
    'message' => 'El ícono para eliminar esta Noticia. Si el usuario no tiene privilegios para eliminar la Noticia, o su nivel de interfaz de usuario es muy bajo, la variable estará vacía.'
  },
  'editIcon' => {
    'lastUpdated' => '1253710417',
    'message' => 'El ícono para editar la Noticia. Si el usuario no tiene privilegios para editar la Noticia, o su nivel de interfaz de usuario es muy bajo, la variable estará vacía.'
  },
  'rssUrl' => {
    'lastUpdated' => '1253710429',
    'message' => 'El URL para la Fuente RSS de este Tópico de Noticias.'
  },
  'standAlone' => {
    'lastUpdated' => '1253710466',
    'message' => 'Un condicional que indica si el Tópico de Noticias está siendo visto directamente a través de su URL, o si está siendo visto como parte de otro contenedor.'
  },
  'stories per topic' => {
    'lastUpdated' => '1253710476',
    'message' => 'Noticias por Tópico'
  },
  'stories per topic help' => {
    'lastUpdated' => '1253710508',
    'message' => 'Indique el número de Noticias desplegadas en las Fuentes RSS y Atom para este Tópico de Noticias, así como cuando el Tópico es visto directamente.'
  },
  'stories short' => {
    'lastUpdated' => '1253710517',
    'message' => 'Noticias por Página'
  },
  'stories short help' => {
    'lastUpdated' => '1253710530',
    'message' => 'Indique el número de Noticias mostradas por página.'
  },
  'story template' => {
    'lastUpdated' => '1253710538',
    'message' => 'Plantilla para Noticia'
  },
  'story template help' => {
    'lastUpdated' => '1253710558',
    'message' => 'Seleccione la Plantilla empleada para desplegar Noticias dentro de este Tópico de Noticias.'
  },
  'story_loop' => {
    'lastUpdated' => '1253710573',
    'message' => 'Un ciclo que itera sobre las Noticias más recientes para este Tópico de Noticias.'
  },
  'storytopic asset template variables title' => {
    'lastUpdated' => '1253710586',
    'message' => 'Variables de Plantilla para Tópico de Noticias'
  },
  'template' => {
    'lastUpdated' => '1253710597',
    'message' => 'Plantilla Principal'
  },
  'template help' => {
    'lastUpdated' => '1253710612',
    'message' => 'Seleccione la Plantilla empleada para desplegar el Tópico de Noticias.'
  },
  'title' => {
    'lastUpdated' => '1253710625',
    'message' => 'El Título de la Noticia.'
  },
  'topStoryCreationDate' => {
    'lastUpdated' => '1253710656',
    'message' => 'La fecha en la que la Noticia principal fue creada o enviada al Archivo de Noticias, como una época Unix.'
  },
  'topStoryImageAlt' => {
    'lastUpdated' => '1253710679',
    'message' => 'El texto alterno para la imagen de la primera foto de la Noticia principal, si existe.'
  },
  'topStoryImageByline' => {
    'lastUpdated' => '1253710706',
    'message' => 'La línea de Atribución para la primera foto de la Noticia principal, si existe.'
  },
  'topStoryImageCaption' => {
    'lastUpdated' => '1253710729',
    'message' => 'La Leyenda para la primera foto de la Noticia principal, si existe.'
  },
  'topStoryImageLink' => {
    'lastUpdated' => '1253710747',
    'message' => 'El URL destino de la primera foto de la Noticia principal, si existe.'
  },
  'topStoryImageTitle' => {
    'lastUpdated' => '1253710766',
    'message' => 'El Título de la primera foto de la Noticia principal, si existe.'
  },
  'topStoryImageUrl' => {
    'lastUpdated' => '1253710781',
    'message' => 'El URL a la primera foto de la Noticia principal, si existe.'
  },
  'topStorySubtitle' => {
    'lastUpdated' => '1253710793',
    'message' => 'El Subtítulo de la Noticia principal.'
  },
  'topStoryTitle' => {
    'lastUpdated' => '1253710806',
    'message' => 'El Título de la Noticia Principal.'
  },
  'topStoryUrl' => {
    'lastUpdated' => '1253710817',
    'message' => 'El URL para ver la Noticia principal.'
  },
  'url' => {
    'lastUpdated' => '1253710827',
    'message' => 'El URL para&nbsp; ver una Noticia.'
  },
  'view template' => {
    'lastUpdated' => '1253710844',
    'message' => 'Plantilla para ver Tópico de Noticias'
  }
}
;

1;

==> webgui_7.10.28.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Spanish/Asset_StoryTopic.pm <==
package WebGUI::i18n::Spanish::Asset_StoryTopic;
use utf8;
our $I18N = {
  'Read more stories' => {
    'lastUpdated' => '1253710295',
    'message' => 'Leer más Noticias.'
  },
  'assetName' => {
    'lastUpdated' => '1253710320',
    'message' => 'Tópico de Noticias'
  },
  'atomUrl' => {
    'lastUpdated' => '1253710334',
    'message' => 'El URL a la Fuente Atom para este Tópico de Noticias.'
  },
  'creationDate' => {
    'lastUpdated' => '1253710354',
    'message' => 'La fecha en que la Noticia fue creada o enviada al Archivo de Noticias, como una época Unix.'
  },
  'deleteIcon' => {
    'lastUpdated' => '1253710389',
    'message' => 'El ícono para eliminar esta Noticia. Si el usuario no tiene privilegios para eliminar la Noticia, o su nivel de interfaz de usuario es muy bajo, la variable estará vacía.'
  },
  'editIcon' => {
    'lastUpdated' => '1253710417',
    'message' => 'El ícono para editar la Noticia. Si el usuario no tiene privilegios para editar la Noticia, o su nivel de interfaz de usuario es muy bajo, la variable estará vacía.'
  },
  'rssUrl' => {
    'lastUpdated' => '1253710429',
    'message' => 'El URL para la Fuente RSS de este Tópico de Noticias.'
  },
  'standAlone' => {
    'lastUpdated' => '1253710466',
    'message' => 'Un condicional que indica si el Tópico de Noticias está siendo visto directamente a través de su URL, o si está siendo visto como parte de otro contenedor.'
  },
  'stories per topic' => {
    'lastUpdated' => '1253710476',
    'message' => 'Noticias por Tópico'
  },
  'stories per topic help' => {
    'lastUpdated' => '1253710508',
    'message' => 'Indique el número de Noticias desplegadas en las Fuentes RSS y Atom para este Tópico de Noticias, así como cuando el Tópico es visto directamente.'
  },
  'stories short' => {
    'lastUpdated' => '1253710517',
    'message' => 'Noticias por Página'
  },
  'stories short help' => {
    'lastUpdated' => '1253710530',
    'message' => 'Indique el número de Noticias mostradas por página.'
  },
  'story template' => {
    'lastUpdated' => '1253710538',
    'message' => 'Plantilla para Noticia'
  },
  'story template help' => {
    'lastUpdated' => '1253710558',
    'message' => 'Seleccione la Plantilla empleada para desplegar Noticias dentro de este Tópico de Noticias.'
  },
  'story_loop' => {
    'lastUpdated' => '1302873359',
    'message' => 'Un ciclo que itera sobre las Noticias más recientes para este Tópico de Noticias.'
  },
  'storytopic asset template variables title' => {
    'lastUpdated' => '1253710586',
    'message' => 'Variables de Plantilla para Tópico de Noticias'
  },
  'template' => {
    'lastUpdated' => '1253710597',
    'message' => 'Plantilla Principal'
  },
  'template help' => {
    'lastUpdated' => '1253710612',
    'message' => 'Seleccione la Plantilla empleada para desplegar el Tópico de Noticias.'
  },
  'title' => {
    'lastUpdated' => '1253710625',
    'message' => 'El Título de la Noticia.'
  },
  'topStory' => {
    'lastUpdated' => '1302873382',
    'message' => 'Contiene el mismo tipo de valores que story_loop, pero para la historia destacada.'
  },
  'topStoryCreationDate' => {
    'lastUpdated' => '1253710656',
    'message' => 'La fecha en la que la Noticia principal fue creada o enviada al Archivo de Noticias, como una época Unix.'
  },
  'topStoryImageAlt' => {
    'lastUpdated' => '1253710679',
    'message' => 'El texto alterno para la imagen de la primera foto de la Noticia principal, si existe.'
  },
  'topStoryImageByline' => {
    'lastUpdated' => '1253710706',
    'message' => 'La línea de Atribución para la primera foto de la Noticia principal, si existe.'
  },
  'topStoryImageCaption' => {
    'lastUpdated' => '1253710729',
    'message' => 'La Leyenda para la primera foto de la Noticia principal, si existe.'
  },
  'topStoryImageLink' => {
    'lastUpdated' => '1253710747',
    'message' => 'El URL destino de la primera foto de la Noticia principal, si existe.'
  },
  'topStoryImageTitle' => {
    'lastUpdated' => '1253710766',
    'message' => 'El Título de la primera foto de la Noticia principal, si existe.'
  },
  'topStoryImageUrl' => {
    'lastUpdated' => '1253710781',
    'message' => 'El URL a la primera foto de la Noticia principal, si existe.'
  },
  'topStorySubtitle' => {
    'lastUpdated' => '1253710793',
    'message' => 'El Subtítulo de la Noticia principal.'
  },
  'topStoryTitle' => {
    'lastUpdated' => '1253710806',
    'message' => 'El Título de la Noticia Principal.'
  },
  'topStoryUrl' => {
    'lastUpdated' => '1253710817',
    'message' => 'El URL para ver la Noticia principal.'
  },
  'url' => {
    'lastUpdated' => '1253710827',
    'message' => 'El URL para&nbsp; ver una Noticia.'
  },
  'view template' => {
    'lastUpdated' => '1253710844',
    'message' => 'Plantilla para ver Tópico de Noticias'
  }
}
;

1;
